﻿namespace UltraGridDragAndDrop
{
    using System;
    using System.ComponentModel;
    using System.Data;
    using System.Drawing;
    using System.Windows.Forms;

    using Infragistics.Win;
    using Infragistics.Win.UltraWinGrid;

    public partial class Form1 : Form
    {
        public Form1()
        {
            this.InitializeComponent();
            this.PopulateGridData();
            this.SetupGridForDragAndDrop(this.ultraGrid1);
            
        }

        private void SetupGridForDragAndDrop(UltraGrid ultraGrid)
        {
            // Allow the Grid control to accept data that the user drop on it
            ultraGrid.AllowDrop = true;

            // Allow user to select a single cell and start dragging it 
            ultraGrid.DisplayLayout.Override.SelectTypeCell = SelectType.SingleAutoDrag;

            // Highlight the selected cell in order user to be able to start dragging it
            ultraGrid.DisplayLayout.Override.CellClickAction = CellClickAction.CellSelect;
        }

        private void ultraGrid1_SelectionDrag(object sender, CancelEventArgs e)
        {
            ultraGrid1.DoDragDrop(ultraGrid1.Selected.Cells, DragDropEffects.Copy | DragDropEffects.Move);
        }

        private void ultraGrid1_DragOver(object sender, DragEventArgs e)
        {
            if (e.Data.GetData(typeof(SelectedCellsCollection)) != null)
            {
                e.Effect = DragDropEffects.Copy;
            }
            else
            {
                e.Effect = DragDropEffects.None;
            }
        }

        private void ultraGrid1_DragDrop(object sender, DragEventArgs e)
        {
            int dropIndexRow;
            int dropIndexCol;
            UIElement uieOver = this.ultraGrid1.DisplayLayout.UIElement.ElementFromPoint(this.ultraGrid1.PointToClient(new Point(e.X, e.Y)));
            UltraGridRow ugrOver = uieOver.GetContext(typeof(UltraGridRow), true) as UltraGridRow;
            UltraGridColumn ugrOverCol = uieOver.GetContext(typeof(UltraGridColumn), true) as UltraGridColumn;
            
            if (ugrOver != null)
            {
                dropIndexRow = ugrOver.Index;
                dropIndexCol = ugrOverCol.Index;
                SelectedCellsCollection SelCells;
                SelCells = (SelectedCellsCollection)e.Data.GetData(typeof(SelectedCellsCollection));
                ultraGrid1.Rows[dropIndexRow].Cells[dropIndexCol].Value = SelCells[0].Value;

            }
        }

        private void PopulateGridData()
        {
            DataSet dataSet = new DataSet();

            DataTable dataTable = dataSet.Tables.Add("table1");
            dataTable.Columns.Add("id", typeof(int)).AutoIncrement = true;
            dataTable.Columns.Add("Name", typeof(string));
            dataTable.Columns.Add("Quantity", typeof(double));
            dataTable.Columns.Add("Price", typeof(double));
            dataTable.Columns.Add("Date", typeof(DateTime));

            dataSet.Tables["table1"].Rows.Add(new object[] { null, "Beverage", 5050.25, 10.2, new DateTime(2008, 04, 22) });
            dataSet.Tables["table1"].Rows.Add(new object[] { null, "Appliances", 51312.123, 90, new DateTime(2012, 05, 10) });
            dataSet.Tables["table1"].Rows.Add(new object[] { null, "FastFood", 26545.16450, 32, new DateTime(2005, 10, 05) });
            dataSet.Tables["table1"].Rows.Add(new object[] { null, "Furniture", 1002, 79, new DateTime(2009, 02, 28) });
            dataSet.Tables["table1"].Rows.Add(new object[] { null, "Meat", 40513, 10.2, new DateTime(2008, 04, 22) });
            dataSet.Tables["table1"].Rows.Add(new object[] { null, "Fruits", 25, 12, new DateTime(2012, 05, 10) });
            dataSet.Tables["table1"].Rows.Add(new object[] { null, "Vegetables", 300, 13, new DateTime(2005, 10, 05) });
            dataSet.Tables["table1"].Rows.Add(new object[] { null, "Cars", 13, 200, new DateTime(2009, 02, 28) });
            dataSet.Tables["table1"].Rows.Add(new object[] { null, "Tools", 60, 15.3, new DateTime(2008, 04, 22) });
            dataSet.Tables["table1"].Rows.Add(new object[] { null, "Estate", 5, 3000, new DateTime(2012, 05, 10) });
            dataSet.Tables["table1"].Rows.Add(new object[] { null, "Motorcycles", 10, 320, new DateTime(2005, 10, 05) });
            dataSet.Tables["table1"].Rows.Add(new object[] { null, "Clothes", 40, 69, new DateTime(2009, 02, 28) });
            dataSet.Tables["table1"].Rows.Add(new object[] { null, "Shoes", 24, 40.6, new DateTime(2008, 04, 22) });
            dataSet.Tables["table1"].Rows.Add(new object[] { null, "Games", 53, 50, new DateTime(2012, 05, 10) });
            dataSet.Tables["table1"].Rows.Add(new object[] { null, "Books", 42, 22, new DateTime(2005, 10, 05) });
            dataSet.Tables["table1"].Rows.Add(new object[] { null, "Movies", 38, 19, new DateTime(2009, 02, 28) });

            ultraGrid1.DataSource = dataSet;
        }
    }
}
